from setuptools import setup

setup(name='cf_wesgrh',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['cf_wesgrh'],
      author_email='arinafim300999@mail.ru',
      zip_safe=False)